Allow limits to apply to the root user, who may want an elevated priority.
--- Linux-PAM-0.75/modules/pam_limits/pam_limits.c
+++ Linux-PAM-0.75/modules/pam_limits/pam_limits.c
@@ -540,11 +540,20 @@
     return PAM_SUCCESS;    
 }
 
-static int setup_limits(const char * uname, int ctrl, struct pam_limit_s *pl)
+static int setup_limits(const char * uname, uid_t uid,
+			int ctrl, struct pam_limit_s *pl)
 {
     int i;
     int retval = PAM_SUCCESS;
     
+    /* do not impose limits on UID 0 accounts */
+    if (uid == 0) {
+        if (ctrl & PAM_DEBUG_ARG)
+            _pam_log(LOG_DEBUG, "user '%s' has UID 0 - no limits imposed",
+                                uname);
+        if(pl->priority > 0)
+            pl->priority = 0;
+    } else
     for (i=0; i<RLIM_NLIMITS; i++) {
         if (pl->limits[i].limit.rlim_cur > pl->limits[i].limit.rlim_max)
             pl->limits[i].limit.rlim_cur = pl->limits[i].limit.rlim_max;
@@ -559,10 +566,10 @@
     if (retval != PAM_SUCCESS)
         retval = LIMIT_ERR;
 
-    if (pl->login_limit > 0) {
+    if ((uid != 0) && (pl->login_limit > 0)) {
         if (check_logins(uname, pl->login_limit, ctrl, pl) == LOGIN_ERR)
             retval |= LOGIN_ERR;
-    } else if (pl->login_limit == 0)
+    } else if ((uid != 0) && (pl->login_limit == 0))
         retval |= LOGIN_ERR;
     return retval;
 }
@@ -597,14 +604,6 @@
         return PAM_SESSION_ERR;
     }
                      
-    /* do not impose limits on UID 0 accounts */
-    if (!pwd->pw_uid) {
-        if (ctrl & PAM_DEBUG_ARG)
-            _pam_log(LOG_DEBUG, "user '%s' have UID 0 - no limits imposed",
-                                user_name);
-        return PAM_SUCCESS;
-    }
-        
     retval = init_limits(&pl);
     if (retval != PAM_SUCCESS) {
         _pam_log(LOG_WARNING, "cannot initialize");
@@ -624,7 +623,7 @@
     if (ctrl & PAM_DO_SETREUID)
 	setreuid(pwd->pw_uid, -1);
 
-    retval = setup_limits(pwd->pw_name, ctrl, &pl);
+    retval = setup_limits(pwd->pw_name, pwd->pw_uid, ctrl, &pl);
     if (retval & LOGIN_ERR) {
 	snprintf(error_buf, sizeof(error_buf), "Too many logins for '%s'.\n",
 		 pwd->pw_name);
